"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.apply = exports.Config = exports.name = void 0;
const koishi_1 = require("koishi");
const Huggingface_1 = __importDefault(require("./Huggingface"));
exports.name = 'diffsinger-huggingface';
exports.Config = koishi_1.Schema.object({
    apiurl: koishi_1.Schema.string().default("https://hf.space/embed/Silentlin/DiffSinger/api/predict/").description("Huggingface Diffsinger Spaces的API地址"),
    songlistUrl: koishi_1.Schema.string().default("https://koishidiffsingerstatic.metalstudio.top/songlist.json").description("按照diffsinger的入参格式排列而成的歌单的地址")
});
function apply(ctx, config) {
    // write your plugin here
    let resultCache = [];
    ctx.command("diffsinger")
        .action(async ({ args, session }) => {
        let songListResponse = await ctx.http.axios(config.songlistUrl, {
            method: "GET",
        });
        let songListJSON = songListResponse.data;
        console.log(songListJSON);
        let songLIst = songListJSON;
        var song = args[0];
        var result;
        let recommend = async () => {
            let names = Object.keys(songLIst);
            let opString = "\n" + names.join("\n");
            return opString;
        };
        if (args.length == 0) {
            return '请输入歌名';
        }
        if (!songLIst[args[0]]) {
            return '没有曲谱唱不出来,建议您试一下以下歌曲' + await recommend();
        }
        console.log("正在合成" + song);
        var params = songLIst[args[0]];
        if (Object.keys(resultCache).includes(JSON.stringify(params))) {
            console.log("从缓存中获取" + song);
            result = resultCache[JSON.stringify(params)];
        }
        else {
            result = await Huggingface_1.default.PredictWithWholeParam(ctx, config.apiurl, params);
            resultCache[JSON.stringify(params)] = result;
        }
        var b64data = result.replace("data:audio/wav;base64,", "base64://");
        console.log("合成" + song + "完成");
        return `[CQ:record,url=${b64data}]]`;
    });
}
exports.apply = apply;
